Module mount

Module mount 

Mount and unmount operations.

Cross-platform abstraction for mouting and unmouting file systems. Extra functionality for specific platforms can be found at crate::os.

Structs

MountOptions
Options used to configure how the volume is mounted.
UnmountOptions
Options used to configure how the volume is unmounted.

Functions

mount
Mounts the file system pointed by volume at mount_point.
unmount
Unmounts the file system pointed by mount_point.